import express from 'express';
import { Logger } from 'winston';
import { CatalogApi as CatalogApi$1, CatalogClient } from '@backstage/catalog-client';
import * as graphql from 'graphql';
import { Entity, CompoundEntityRef } from '@backstage/catalog-model';
import DataLoader from 'dataloader';
import { GetEnvelopedFn } from '@envelop/core';

declare type EntityRef = string | CompoundEntityRef;
declare type Loader = DataLoader<EntityRef, Entity>;
interface ResolverContext {
    loader: Loader;
    catalog: CatalogApi;
}
declare type CatalogApi = Pick<CatalogApi$1, "getEntityByRef">;

interface App {
    (): ReturnType<GetEnvelopedFn<ResolverContext>>;
}
declare const schema: graphql.GraphQLSchema;
declare function createApp(catalog: CatalogApi): App;

interface RouterOptions {
    logger: Logger;
    catalog: CatalogClient;
}

declare function createRouter(options: RouterOptions): Promise<express.Router>;

export { App, RouterOptions, createApp, createRouter, schema };
